@@ -26,25 +26,23 @@ def capture_on_commit_callbacks(
     try:
         yield callbacks
     finally:
-        callback_count = len(connections[using].run_on_commit)
         while True:
-            run_on_commit = connections[using].run_on_commit[start_count:]
-            callbacks[:] = [func for sids, func in run_on_commit]
-            if execute:
-                for callback in callbacks:
+            callback_count = len(connections[using].run_on_commit)
+            for _, callback in connections[using].run_on_commit[start_count:]:
+                callbacks.append(callback)
+                if execute:
                     callback()
 
-            if len(connections[using].run_on_commit) == callback_count:
+            if callback_count == len(connections[using].run_on_commit):
                 break
-            start_count = callback_count - 1
-            callback_count = len(connections[using].run_on_commit)
+            start_count = callback_count
 
 
 class TestCaseMixin:
     @classmethod
     def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:
         check_django_version()
-        super().__init_subclass__(*args, **kwargs)  # type: ignore [call-arg]
+        super().__init_subclass__(*args, **kwargs)
 
     @classmethod
     def captureOnCommitCallbacks(
